#ifndef CENTRALWIDGET_H
#define CENTRALWIDGET_H

#include <QWidget>
#include <QtNetwork/QTcpSocket>

#include "reversigame.h"

enum P2PSTATE {WAIT_SERVER_VERSION, WAIT_CLIENT_VERSION, WAIT_SERVER_NEW_GAME, RUNNING, SERVER_PAUSED, CLIENT_PAUSED};

class QGridLayout;
class QVBoxLayout;
class QTcpServer;
class QTcpSocket;
class FieldView;
class InfoPanel;
class ModePanel;

class CentralWidget : public QWidget
{
    Q_OBJECT
public:
    explicit CentralWidget(QWidget *parent, ReversiGame &reversiGame);
    void showInfoPanels();
    /** 
     * @brief Starts new game
     */
    void newGame();

private:
    bool newGameP2PServer();
    bool newGameP2PClient();

private:
    QGridLayout *layout_;
    QVBoxLayout *infoLayout_;
    QTcpServer *gameServer_;
    QTcpSocket  *gameClient_;
    QTcpSocket  *gameConnection_;
    FieldView *fieldView_;
    InfoPanel *infoPanel_;
    ModePanel *modePanel_;
    int gameMode_;
    P2PSTATE P2PState_;
    int strength_;
    bool isNetworkGame_;

    ReversiGame &reversiGame_;

public slots:
    void slotPlayerStep(int x, int y);

private slots:
    void stepUnavailable();
    void slotOrientationChanged();
    void slotReadNetworkData();
    void displayP2PError(QAbstractSocket::SocketError socketError);
};

#endif // CENTRALWIDGET_H
